@@ -1,26 +1,34 @@
 /*
- * Copyright (C) 2015-2022 VMware, Inc. All Rights Reserved.
+ * Copyright (C) 2015-2021 VMware, Inc. All Rights Reserved.
  *
  * Licensed under the GNU Lesser General Public License v2.1 (the "License");
  * you may not use this file except in compliance with the License. The terms
  * of the License are located in the COPYING file of this distribution.
  */
 
+/*
+ * Header : defines.h
+ *
+ * Abstract :
+ *
+ *            tdnfclientlib
+ *
+ *            client library
+ *
+ * Authors  : Priyesh Padmavilasom (ppadmavilasom@vmware.com)
+ */
+
 #pragma once
 
 #include "config.h"
 
-/*
- * creating this under /var/run because /var/run/lock doesn't exist
- * in fedora docker images and as a result ci fails
- */
-#define TDNF_INSTANCE_LOCK_FILE     "/var/run/.tdnf-instance-lockfile"
-
-
 typedef enum
 {
+    /* this should be a bitmask */
     DETAIL_LIST,
-    DETAIL_INFO
+    DETAIL_INFO,
+    DETAIL_CHANGELOG,
+    DETAIL_SOURCEPKG
 }TDNF_PKG_DETAIL;
 
 #define BAIL_ON_TDNF_RPM_ERROR(dwError) \
@@ -41,6 +49,8 @@ typedef enum
         }                                                          \
     } while(0)
 
+#define STR_IS_TRUE(s) ((s) && (!strcmp((s), "1") || !strcasecmp((s), "true")))
+
 //Misc
 #define TDNF_RPM_EXT                      ".rpm"
 #define TDNF_NAME                         "tdnf"
@@ -51,6 +61,7 @@ typedef enum
 #define TDNF_REPOMD_TYPE_PRIMARY          "primary"
 #define TDNF_REPOMD_TYPE_FILELISTS        "filelists"
 #define TDNF_REPOMD_TYPE_UPDATEINFO       "updateinfo"
+#define TDNF_REPOMD_TYPE_OTHER            "other"
 
 //Repo defines
 #define TDNF_REPO_EXT                     ".repo"
@@ -76,8 +87,6 @@ typedef enum
 #define TDNF_PLUGIN_CONF_KEY_ENABLED      "enabled"
 #define TDNF_CONF_KEY_EXCLUDE             "excludepkgs"
 #define TDNF_CONF_KEY_MINVERSIONS         "minversions"
-#define TDNF_CONF_KEY_OPENMAX             "openmax"
-
 //Repo file key names
 #define TDNF_REPO_KEY_BASEURL             "baseurl"
 #define TDNF_REPO_KEY_ENABLED             "enabled"
@@ -98,8 +107,6 @@ typedef enum
 #define TDNF_REPO_KEY_SSL_CA_CERT         "sslcacert"
 #define TDNF_REPO_KEY_SSL_CLI_CERT        "sslclientcert"
 #define TDNF_REPO_KEY_SSL_CLI_KEY         "sslclientkey"
-#define TDNF_REPO_KEY_SKIP_MD_FILELISTS   "skip_md_filelists"
-#define TDNF_REPO_KEY_SKIP_MD_UPDATEINFO  "skip_md_updateinfo"
 
 //setopt keys
 #define TDNF_SETOPT_KEY_REPOSDIR          "reposdir"
@@ -121,8 +128,6 @@ typedef enum
 #define TDNF_SOLVCACHE_DIR_NAME           "solvcache"
 #define TDNF_REPO_METADATA_EXPIRE_NEVER   "never"
 
-#define TDNF_DEFAULT_OPENMAX              1024
-
 // repo default settings
 #define TDNF_REPO_DEFAULT_ENABLED         0
 #define TDNF_REPO_DEFAULT_SKIP            0
@@ -133,9 +138,8 @@ typedef enum
 #define TDNF_REPO_DEFAULT_SSLVERIFY       1
 #define TDNF_REPO_DEFAULT_RETRIES         10
 #define TDNF_REPO_DEFAULT_PRIORITY        50
-#define TDNF_REPO_DEFAULT_METADATA_EXPIRE "172800" // 48 hours in seconds
-#define TDNF_REPO_DEFAULT_SKIP_MD_FILELISTS  0
-#define TDNF_REPO_DEFAULT_SKIP_MD_UPDATEINFO 0
+#define TDNF_REPO_DEFAULT_METADATA_EXPIRE 172800 // 48 hours in seconds
+#define TDNF_REPO_DEFAULT_METADATA_EXPIRE_STR STRINGIFYX(TDNF_REPO_DEFAULT_METADATA_EXPIRE)
 
 // var names
 #define TDNF_VAR_RELEASEVER               "$releasever"
@@ -215,10 +219,9 @@ typedef enum
     {ERROR_TDNF_PERM, "ERROR_TDNF_PERM", "Operation not permitted. You have to be root."},\
     {ERROR_TDNF_OPT_NOT_FOUND, "ERROR_TDNF_OPT_NOT_FOUND", "A required option was not found"},\
     {ERROR_TDNF_OPERATION_ABORTED, "ERROR_TDNF_OPERATION_ABORTED", "Operation aborted."},\
-    {ERROR_TDNF_INVALID_INPUT, "ERROR_TDNF_INVALID_INPUT", "Invalid input."},\
     {ERROR_TDNF_CACHE_DISABLED, "ERROR_TDNF_CACHE_DISABLED", "cache only is set, but no repo data found"},\
-    {ERROR_TDNF_EVENT_CTXT_ITEM_NOT_FOUND, "ERROR_TDNF_EVENT_CTXT_ITEM_NOT_FOUND", "An event context item was not found. This is usually related to plugin events. Try --noplugins to disable all plugins or --disableplugin=<plugin> to disable a specific one. You can permanently disable an offending plugin by setting enable=0 in the plugin config file."},\
-    {ERROR_TDNF_EVENT_CTXT_ITEM_INVALID_TYPE, "ERROR_TDNF_EVENT_CTXT_ITEM_INVALID_TYPE", "An event item type had a mismatch. This is usually related to plugin events. Try --noplugins to disable all plugins or --disableplugin=<plugin> to disable a specific one. You can permanently disable an offending plugin by setting enable=0 in the plugin config file."},\
+    {ERROR_TDNF_EVENT_CTXT_ITEM_NOT_FOUND, "ERROR_TDNF_EVENT_CTXT_ITEM_NOT_FOUND", "An event context item was not found. This is usually related to plugin events. Try --noplugins to deactivate all plugins or --disableplugin=<plugin> to deactivate a specific one. You can permanently deactivate an offending plugin by setting enable=0 in the plugin config file."},\
+    {ERROR_TDNF_EVENT_CTXT_ITEM_INVALID_TYPE, "ERROR_TDNF_EVENT_CTXT_ITEM_INVALID_TYPE", "An event item type had a mismatch. This is usually related to plugin events. Try --noplugins to deactivate all plugins or --disableplugin=<plugin> to deactivate a specific one. You can permanently deactivate an offending plugin by setting enable=0 in the plugin config file."},\
     {ERROR_TDNF_NO_GPGKEY_CONF_ENTRY,         "ERROR_TDNF_NO_GPGKEY_CONF_ENTRY",         "gpgkey entry is missing for this repo. please add gpgkey in repo file or use --nogpgcheck to ignore."}, \
     {ERROR_TDNF_URL_INVALID,                          "ERROR_TDNF_URL_INVALID",          "URL is invalid."}, \
     {ERROR_TDNF_BASEURL_DOES_NOT_EXISTS,             "ERROR_TDNF_BASEURL_DOES_NOT_EXISTS",             "Base URL and Metalink URL not found in the repo file"},\
