@@ -62,6 +62,8 @@ TDNFPrepareAllPackages(
     PTDNF_CMD_ARGS pCmdArgs = NULL;
     int nCmdIndex = 0;
     int nPkgIndex = 0;
+    int nIsFile = 0;
+    int nDummy = 0;
     char* pszPkgName = NULL;
     char* pszName = NULL;
     Queue queueLocal = {0};
@@ -129,6 +131,7 @@ TDNFPrepareAllPackages(
        for(nCmdIndex = 1; nCmdIndex < pCmdArgs->nCmdCount; ++nCmdIndex)
        {
            pszPkgName = pCmdArgs->ppszCmds[nCmdIndex];
+
            if(TDNFIsGlob(pszPkgName))
            {
                queue_empty(&queueLocal);
@@ -167,6 +170,27 @@ TDNFPrepareAllPackages(
            }
            else
            {
+               dwError = TDNFIsFileOrSymlink(pszPkgName, &nIsFile);
+               BAIL_ON_TDNF_ERROR(dwError);
+
+               if (nIsFile)
+               {
+                   continue;
+               }
+
+               dwError = TDNFUriIsRemote(pszPkgName, &nDummy);
+               if (dwError == 0)
+               {
+                 /* URL => cmd line pkg, already handled */
+                 dwError = 0;
+                 continue;
+               }
+               else if (dwError == ERROR_TDNF_URL_INVALID)
+               {
+                   dwError = 0;
+               }
+               BAIL_ON_TDNF_ERROR(dwError);
+
                dwError = TDNFPrepareAndAddPkg(
                              pTdnf,
                              pszPkgName,
@@ -314,6 +338,11 @@ TDNFPrepareSinglePkg(
 
     //Check if this is a known package. If not add to unresolved
     dwError = SolvCountPkgByName(pSack, pszPkgName, &dwCount);
+    if (dwError == ERROR_TDNF_NO_MATCH)
+    {
+        pr_err("%s package not found or not installed\n", pszPkgName);
+    }
+
     BAIL_ON_TDNF_ERROR(dwError);
     if (dwCount == 0)
     {
@@ -397,25 +426,25 @@ error:
         dwError = 0;
         if(nShowAlreadyInstalled)
         {
-            fprintf(stderr, "Package %s is already installed.\n", pszPkgName);
+            pr_err("Package %s is already installed.\n", pszPkgName);
         }
     }
     if(dwError == ERROR_TDNF_NO_UPGRADE_PATH)
     {
         dwError = 0;
-        fprintf(stderr, "There is no upgrade path for %s.\n", pszPkgName);
+        pr_err("There is no upgrade path for %s.\n", pszPkgName);
     }
     if(dwError == ERROR_TDNF_NO_DOWNGRADE_PATH)
     {
         dwError = 0;
-        fprintf(stderr, "There is no downgrade path for %s.\n", pszPkgName);
+        pr_err("There is no downgrade path for %s.\n", pszPkgName);
     }
     if(dwError == ERROR_TDNF_NO_SEARCH_RESULTS)
     {
         dwError = 0;
         if(TDNFAddNotResolved(ppszPkgsNotResolved, pszPkgName))
         {
-            fprintf(stderr, "Error while adding not resolved packages\n");
+            pr_err("Error while adding not resolved packages\n");
         }
     }
     if(dwError == ERROR_TDNF_ERASE_NEEDS_INSTALL)
