@@ -113,13 +113,22 @@ TDNFProvides(
     PTDNF_PKG_INFO* ppPkgInfo
     );
 
-//query repo
+//sync repo
 uint32_t
 TDNFRepoSync(
     PTDNF pTdnf,
     PTDNF_REPOSYNC_ARGS pReposyncArgs
     );
 
+//query repo
+uint32_t
+TDNFRepoQuery(
+    PTDNF pTdnf,
+    PTDNF_REPOQUERY_ARGS pRepoqueryArgs,
+    PTDNF_PKG_INFO* ppPkgInfo,
+    uint32_t *pdwCount
+    );
+
 //Show update info for specified scope
 uint32_t
 TDNFUpdateInfo(
@@ -136,7 +145,7 @@ TDNFUpdateInfoSummary(
     PTDNF_UPDATEINFO_SUMMARY* ppSummary
     );
 
-//sanity check. displays current installed count.
+//confidence check. displays current installed count.
 //should be same as rpm -qa | wc -l
 uint32_t
 TDNFCountCommand(
@@ -223,6 +232,11 @@ TDNFFreePackageInfoArray(
     uint32_t dwLength
     );
 
+void
+TDNFFreeChangeLogEntry(
+    PTDNF_PKG_CHANGELOG_ENTRY pEntry
+);
+
 void
 TDNFFreeRepos(
     PTDNF_REPO_DATA pRepos
