@@ -61,6 +61,33 @@ TDNFCliShowHelp(
     pr_crit("           [--downloadonly]\n");
     pr_crit("           [--downloaddir=<directory>]\n");
     pr_crit("\n");
+    pr_crit("repoquery select options:\n");
+    pr_crit("           [--available\n");
+    pr_crit("           [--duplicates\n");
+    pr_crit("           [--extras\n");
+    pr_crit("           [--file <file>\n");
+    pr_crit("           [--installed\n");
+    pr_crit("           [--whatdepends <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatrequires <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatenhances <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatobsoletes <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatprovides <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatrecommends <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatrequires <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatsuggests <capability1>[,<capability2>[..]]]\n");
+    pr_crit("           [--whatsupplements <capability1>[,<capability2>[..]]]\n");
+    pr_crit("repoquery query options:\n");
+    pr_crit("           [--depends\n");
+    pr_crit("           [--enhances\n");
+    pr_crit("           [--list\n");
+    pr_crit("           [--obsoletes\n");
+    pr_crit("           [--provides\n");
+    pr_crit("           [--recommends\n");
+    pr_crit("           [--requires\n");
+    pr_crit("           [--requires-pre\n");
+    pr_crit("           [--suggests\n");
+    pr_crit("           [--supplements\n");
+    pr_crit("\n");
     pr_crit("reposync options:\n");
     pr_crit("           [--arch=<arch> [--arch=<arch> [..]]\n");
     pr_crit("           [--delete]\n");
@@ -92,6 +119,7 @@ TDNFCliShowHelp(
     pr_crit("remove                    Remove a package or packages from your system\n");
     pr_crit("reinstall                 reinstall a package\n");
     pr_crit("repolist                  Display the configured software repositories\n");
+    pr_crit("repoquery                 Query repositories\n");
     pr_crit("reposync                  Download all packages from one or more repositories to a directory\n");
     pr_crit("search                    Search package details for the given string\n");
     pr_crit("update                    Upgrade a package or packages on your system (same as 'upgrade')\n");
